@@ -126,8 +126,10 @@ gst_aravis_get_all_camera_caps (GstAravis *gst_aravis, GError **error)
 	if (is_frame_rate_available) {
 		if (!local_error) arv_camera_get_frame_rate_bounds (gst_aravis->camera,
 								    &min_frame_rate, &max_frame_rate, &local_error);
-		gst_util_double_to_fraction (min_frame_rate, &min_frame_rate_numerator, &min_frame_rate_denominator);
-		gst_util_double_to_fraction (max_frame_rate, &max_frame_rate_numerator, &max_frame_rate_denominator);
+		if (!local_error) {
+			gst_util_double_to_fraction (min_frame_rate, &min_frame_rate_numerator, &min_frame_rate_denominator);
+			gst_util_double_to_fraction (max_frame_rate, &max_frame_rate_numerator, &max_frame_rate_denominator);
+		}
 	}
 	if (local_error) {
 		g_propagate_error (error, local_error);
@@ -198,6 +200,10 @@ gst_aravis_set_caps (GstBaseSrc *src, GstCaps *caps)
 	GstCaps *orig_fixed_caps = NULL;
 	gboolean result = FALSE;
 	gboolean is_frame_rate_available;
+	gboolean is_gain_available;
+	gboolean is_gain_auto_available;
+	gboolean is_exposure_time_available;
+	gboolean is_exposure_auto_available;
 
 	GST_LOG_OBJECT (gst_aravis, "Requested caps = %" GST_PTR_FORMAT, caps);
 
@@ -209,6 +215,10 @@ gst_aravis_set_caps (GstBaseSrc *src, GstCaps *caps)
 		goto errored;
 
 	is_frame_rate_available = arv_camera_is_frame_rate_available (gst_aravis->camera, NULL);
+	is_gain_available = arv_camera_is_gain_available (gst_aravis->camera, NULL);
+	is_gain_auto_available = arv_camera_is_gain_auto_available (gst_aravis->camera, NULL);
+	is_exposure_time_available = arv_camera_is_exposure_time_available (gst_aravis->camera, NULL);
+	is_exposure_auto_available = arv_camera_is_exposure_auto_available (gst_aravis->camera, NULL);
 
 	gst_structure_get_int (structure, "width", &width);
 	gst_structure_get_int (structure, "height", &height);
@@ -271,28 +281,28 @@ gst_aravis_set_caps (GstBaseSrc *src, GstCaps *caps)
 		GST_DEBUG_OBJECT (gst_aravis, "Actual frame rate = %g Hz",
 				  arv_camera_get_frame_rate (gst_aravis->camera, NULL));
 
-	if (!error && gst_aravis->gain_auto_set) {
+	if (is_gain_auto_available && !error && gst_aravis->gain_auto_set) {
 		arv_camera_set_gain_auto (gst_aravis->camera, gst_aravis->gain_auto, &error);
 		GST_DEBUG_OBJECT (gst_aravis, "Auto Gain = %s", arv_auto_to_string(gst_aravis->gain_auto));
 	}
-	if (gst_aravis->gain_auto == ARV_AUTO_OFF) {
+	if (is_gain_available && gst_aravis->gain_auto == ARV_AUTO_OFF) {
 		if (gst_aravis->gain >= 0) {
 			GST_DEBUG_OBJECT (gst_aravis, "Gain = %g", gst_aravis->gain);
-			if (!error && !gst_aravis->gain_auto_set)
+			if (is_gain_auto_available && !error && !gst_aravis->gain_auto_set)
 				arv_camera_set_gain_auto (gst_aravis->camera, ARV_AUTO_OFF, &error);
 			if (!error) arv_camera_set_gain (gst_aravis->camera, gst_aravis->gain, &error);
 		}
 		GST_DEBUG_OBJECT (gst_aravis, "Actual gain = %g", arv_camera_get_gain (gst_aravis->camera, NULL));
 	}
 
-	if (!error && gst_aravis->exposure_auto_set) {
+	if (is_exposure_auto_available && !error && gst_aravis->exposure_auto_set) {
 		arv_camera_set_exposure_time_auto (gst_aravis->camera, gst_aravis->exposure_auto, &error);
 		GST_DEBUG_OBJECT (gst_aravis, "Auto Exposure = %s", arv_auto_to_string(gst_aravis->exposure_auto));
 	}
-	if (gst_aravis->exposure_auto == ARV_AUTO_OFF) {
+	if (is_exposure_time_available && gst_aravis->exposure_auto == ARV_AUTO_OFF) {
 		if (gst_aravis->exposure_time_us > 0.0) {
 			GST_DEBUG_OBJECT (gst_aravis, "Exposure = %g µs", gst_aravis->exposure_time_us);
-			if (!error && !gst_aravis->exposure_auto_set)
+			if (is_exposure_auto_available && !error && !gst_aravis->exposure_auto_set)
 				arv_camera_set_exposure_time_auto (gst_aravis->camera, ARV_AUTO_OFF, &error);
 			if (!error) arv_camera_set_exposure_time (gst_aravis->camera, gst_aravis->exposure_time_us, &error);
 		}
@@ -695,7 +705,7 @@ gst_aravis_set_property (GObject * object, guint prop_id,
 		case PROP_GAIN:
 			GST_OBJECT_LOCK (gst_aravis);
 			gst_aravis->gain = g_value_get_double (value);
-			if (gst_aravis->camera != NULL)
+			if (gst_aravis->camera != NULL && arv_camera_is_gain_available (gst_aravis->camera, NULL))
 				arv_camera_set_gain (gst_aravis->camera, gst_aravis->gain, NULL);
 			GST_OBJECT_UNLOCK (gst_aravis);
 			break;
@@ -703,14 +713,15 @@ gst_aravis_set_property (GObject * object, guint prop_id,
 			GST_OBJECT_LOCK (gst_aravis);
 			gst_aravis->gain_auto = g_value_get_enum (value);
 			gst_aravis->gain_auto_set = TRUE;
-			if (gst_aravis->camera != NULL)
+			if (gst_aravis->camera != NULL && arv_camera_is_gain_auto_available (gst_aravis->camera, NULL))
 				arv_camera_set_gain_auto (gst_aravis->camera, gst_aravis->gain_auto, NULL);
 			GST_OBJECT_UNLOCK (gst_aravis);
 			break;
 		case PROP_EXPOSURE:
 			GST_OBJECT_LOCK (gst_aravis);
 			gst_aravis->exposure_time_us = g_value_get_double (value);
-			if (gst_aravis->camera != NULL)
+			if (gst_aravis->camera != NULL &&
+			    arv_camera_is_exposure_time_available (gst_aravis->camera, NULL))
 				arv_camera_set_exposure_time (gst_aravis->camera, gst_aravis->exposure_time_us, NULL);
 			GST_OBJECT_UNLOCK (gst_aravis);
 			break;
@@ -718,7 +729,8 @@ gst_aravis_set_property (GObject * object, guint prop_id,
 			GST_OBJECT_LOCK (gst_aravis);
 			gst_aravis->exposure_auto = g_value_get_enum (value);
 			gst_aravis->exposure_auto_set = TRUE;
-			if (gst_aravis->camera != NULL)
+			if (gst_aravis->camera != NULL &&
+			    arv_camera_is_exposure_auto_available (gst_aravis->camera, NULL))
 				arv_camera_set_exposure_time_auto (gst_aravis->camera, gst_aravis->exposure_auto, NULL);
 			GST_OBJECT_UNLOCK (gst_aravis);
 			break;
@@ -783,7 +795,8 @@ gst_aravis_get_property (GObject * object, guint prop_id, GValue * value,
 			break;
 		case PROP_GAIN_AUTO:
 			GST_OBJECT_LOCK (gst_aravis);
-			if (!gst_aravis->gain_auto_set && gst_aravis->camera) {
+			if (!gst_aravis->gain_auto_set && gst_aravis->camera != NULL &&
+			    arv_camera_is_gain_auto_available (gst_aravis->camera, NULL)) {
 				gst_aravis->gain_auto = arv_camera_get_gain_auto(gst_aravis->camera, NULL);
 			}
 			g_value_set_enum (value, gst_aravis->gain_auto);
@@ -794,7 +807,8 @@ gst_aravis_get_property (GObject * object, guint prop_id, GValue * value,
 			break;
 		case PROP_EXPOSURE_AUTO:
 			GST_OBJECT_LOCK (gst_aravis);
-			if (!gst_aravis->exposure_auto_set && gst_aravis->camera) {
+			if (!gst_aravis->exposure_auto_set && gst_aravis->camera != NULL &&
+			    arv_camera_is_exposure_auto_available (gst_aravis->camera, NULL)) {
 				gst_aravis->exposure_auto = arv_camera_get_exposure_time_auto(gst_aravis->camera, NULL);
 			}
 			g_value_set_enum (value, gst_aravis->exposure_auto);
