@@ -34,20 +34,7 @@
 G_BEGIN_DECLS
 
 #define ARV_TYPE_DOM_DOCUMENT             (arv_dom_document_get_type ())
-#define ARV_DOM_DOCUMENT(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), ARV_TYPE_DOM_DOCUMENT, ArvDomDocument))
-#define ARV_DOM_DOCUMENT_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), ARV_TYPE_DOM_DOCUMENT, ArvDomDocumentClass))
-#define ARV_IS_DOM_DOCUMENT(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ARV_TYPE_DOM_DOCUMENT))
-#define ARV_IS_DOM_DOCUMENT_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), ARV_TYPE_DOM_DOCUMENT))
-#define ARV_DOM_DOCUMENT_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS((obj), ARV_TYPE_DOM_DOCUMENT, ArvDomDocumentClass))
-
-typedef struct _ArvDomDocumentClass ArvDomDocumentClass;
-
-struct _ArvDomDocument {
-	ArvDomNode node;
-
-	char *		url;
-
-};
+G_DECLARE_DERIVABLE_TYPE (ArvDomDocument, arv_dom_document, ARV, DOM_DOCUMENT, ArvDomNode)
 
 struct _ArvDomDocumentClass {
 	ArvDomNodeClass parent_class;
@@ -57,8 +44,6 @@ struct _ArvDomDocumentClass {
 	ArvDomText * 	(*create_text_node) 	(ArvDomDocument* self, const char *data);
 };
 
-GType arv_dom_document_get_type (void);
-
 ArvDomElement* 	arv_dom_document_get_document_element 	(ArvDomDocument* self);
 ArvDomElement* 	arv_dom_document_create_element 	(ArvDomDocument* self, const char *tag_name);
 ArvDomText* 	arv_dom_document_create_text_node 	(ArvDomDocument* self, const char *data);
