@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2010 Emmanuel Pacaud
+ * Copyright © 2009-2019 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,7 +25,7 @@
 static unsigned int
 _from_string (const char *string, const char **strings, unsigned int n_strings)
 {
-	int i;
+	unsigned int i;
 
 	if (string == NULL)
 		return 0;
