@@ -25,13 +25,21 @@
  * @short_description: Fake device
  */
 
+#include <arvdeviceprivate.h>
 #include <arvfakedeviceprivate.h>
 #include <arvfakestreamprivate.h>
 #include <arvfakecamera.h>
 #include <arvgc.h>
 #include <arvdebug.h>
 
+enum
+{
+	PROP_0,
+	PROP_FAKE_DEVICE_SERIAL_NUMBER,
+};
+
 typedef struct {
+	char *serial_number;
 	ArvFakeCamera *camera;
 	ArvGc *genicam;
 } ArvFakeDevicePrivate;
@@ -51,11 +59,9 @@ G_DEFINE_TYPE_WITH_CODE (ArvFakeDevice, arv_fake_device, ARV_TYPE_DEVICE, G_ADD_
 /* ArvDevice implemenation */
 
 static ArvStream *
-arv_fake_device_create_stream (ArvDevice *device, ArvStreamCallback callback, void *user_data)
+arv_fake_device_create_stream (ArvDevice *device, ArvStreamCallback callback, void *user_data, GError **error)
 {
-	ArvFakeDevicePrivate *priv = arv_fake_device_get_instance_private (ARV_FAKE_DEVICE (device));
-
-	return arv_fake_stream_new (priv->camera, callback, user_data);
+	return arv_fake_stream_new (ARV_FAKE_DEVICE (device), callback, user_data, error);
 }
 
 static const char *
@@ -111,6 +117,8 @@ arv_fake_device_write_register (ArvDevice *device, guint64 address, guint32 valu
  * @device: a fake device
  *
  * Return value: (transfer none): the #ArvFakeCamera used by this device instance.
+ *
+ * Since: 0.8.0
  */
 
 ArvFakeCamera *
@@ -123,27 +131,20 @@ arv_fake_device_get_fake_camera	(ArvFakeDevice *device)
 	return priv->camera;
 }
 
+/**
+ * arv_fake_device_new:
+ * @serial_number: fake device serial number
+ * @error: a #GError placeholder, %NULL to ignore
+ *
+ * Returns: a newly created #ArvDevice simulating a real device
+ *
+ * Since: 0.8.0
+ */
+
 ArvDevice *
-arv_fake_device_new (const char *serial_number)
+arv_fake_device_new (const char *serial_number, GError **error)
 {
-	ArvFakeDevicePrivate *priv;
-	ArvFakeDevice *fake_device;
-	ArvFakeCamera *fake_camera;
-	const char *genicam_xml;
-	gsize genicam_xml_size;
-
-	g_return_val_if_fail (serial_number != NULL, NULL);
-
-	fake_camera = arv_fake_camera_new_full (serial_number, NULL);
-	genicam_xml = arv_fake_camera_get_genicam_xml (fake_camera, &genicam_xml_size);
-
-	fake_device = g_object_new (ARV_TYPE_FAKE_DEVICE, NULL);
-
-	priv = arv_fake_device_get_instance_private (fake_device);
-	priv->camera = fake_camera;
-	priv->genicam = arv_gc_new (ARV_DEVICE (fake_device), genicam_xml, genicam_xml_size);
-
-	return ARV_DEVICE (fake_device);
+	return g_initable_new (ARV_TYPE_FAKE_DEVICE, NULL, error, "serial-number", serial_number, NULL);
 }
 
 static void
@@ -156,12 +157,62 @@ arv_fake_device_finalize (GObject *object)
 {
 	ArvFakeDevicePrivate *priv = arv_fake_device_get_instance_private (ARV_FAKE_DEVICE (object));
 
-	g_object_unref (priv->genicam);
-	g_object_unref (priv->camera);
+	g_clear_pointer (&priv->serial_number, g_free);
+	g_clear_object (&priv->genicam);
+	g_clear_object (&priv->camera);
 
 	G_OBJECT_CLASS (arv_fake_device_parent_class)->finalize (object);
 }
 
+static void
+arv_fake_device_constructed (GObject *self)
+{
+	ArvFakeDevicePrivate *priv = arv_fake_device_get_instance_private (ARV_FAKE_DEVICE (self));
+	const char *genicam_xml;
+	gsize genicam_xml_size;
+
+	if (priv->serial_number == NULL) {
+		arv_device_take_init_error (ARV_DEVICE (self),
+					    g_error_new (ARV_DEVICE_ERROR, ARV_DEVICE_ERROR_NOT_FOUND,
+							 "Can't construct a fake device without a serial number"));
+		return;
+	}
+
+	priv->camera = arv_fake_camera_new_full (priv->serial_number, NULL);
+	genicam_xml = arv_fake_camera_get_genicam_xml (priv->camera, &genicam_xml_size);
+
+	if (genicam_xml == NULL) {
+		arv_device_take_init_error (ARV_DEVICE (self),
+					    g_error_new (ARV_DEVICE_ERROR, ARV_DEVICE_ERROR_GENICAM_NOT_FOUND,
+							 "Genicam data not found"));
+		return;
+	}
+	priv->genicam = arv_gc_new (ARV_DEVICE (self), genicam_xml, genicam_xml_size);
+	if (!ARV_IS_GC (priv->genicam)) {
+		arv_device_take_init_error (ARV_DEVICE (self),
+					    g_error_new (ARV_DEVICE_ERROR, ARV_DEVICE_ERROR_GENICAM_NOT_FOUND,
+							 "Invalid Genicam data"));
+		return;
+	}
+}
+
+static void
+arv_fake_device_set_property (GObject *self, guint prop_id, const GValue *value, GParamSpec *pspec)
+{
+	ArvFakeDevicePrivate *priv = arv_fake_device_get_instance_private (ARV_FAKE_DEVICE (self));
+
+	switch (prop_id)
+	{
+		case PROP_FAKE_DEVICE_SERIAL_NUMBER:
+			g_free (priv->serial_number);
+			priv->serial_number = g_value_dup_string (value);
+			break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (self, prop_id, pspec);
+			break;
+	}
+}
+
 static void
 arv_fake_device_class_init (ArvFakeDeviceClass *fake_device_class)
 {
@@ -169,6 +220,8 @@ arv_fake_device_class_init (ArvFakeDeviceClass *fake_device_class)
 	ArvDeviceClass *device_class = ARV_DEVICE_CLASS (fake_device_class);
 
 	object_class->finalize = arv_fake_device_finalize;
+	object_class->constructed = arv_fake_device_constructed;
+	object_class->set_property = arv_fake_device_set_property;
 
 	device_class->create_stream = arv_fake_device_create_stream;
 	device_class->get_genicam_xml = arv_fake_device_get_genicam_xml;
@@ -177,4 +230,13 @@ arv_fake_device_class_init (ArvFakeDeviceClass *fake_device_class)
 	device_class->write_memory = arv_fake_device_write_memory;
 	device_class->read_register = arv_fake_device_read_register;
 	device_class->write_register = arv_fake_device_write_register;
+
+	g_object_class_install_property
+		(object_class,
+		 PROP_FAKE_DEVICE_SERIAL_NUMBER,
+		 g_param_spec_string ("serial-number",
+				      "Serial number",
+				      "Fake device serial number",
+				      NULL,
+				      G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 }
