@@ -71,6 +71,7 @@ typedef struct {
 	ArvBuffer *buffer;
 
 	ArvRegisterCachePolicy cache_policy;
+	ArvRangeCheckPolicy range_check_policy;
 } ArvGcPrivate;
 
 struct _ArvGc {
@@ -365,6 +366,22 @@ arv_gc_get_register_cache_policy (ArvGc *genicam)
 	return genicam->priv->cache_policy;
 }
 
+void
+arv_gc_set_range_check_policy (ArvGc *genicam, ArvRangeCheckPolicy policy)
+{
+	g_return_if_fail (ARV_IS_GC (genicam));
+
+	genicam->priv->range_check_policy = policy;
+}
+
+ArvRangeCheckPolicy
+arv_gc_get_range_check_policy (ArvGc *genicam)
+{
+	g_return_val_if_fail (ARV_IS_GC (genicam), ARV_RANGE_CHECK_POLICY_DISABLE);
+
+	return genicam->priv->range_check_policy;
+}
+
 static void
 _weak_notify_cb (gpointer data, GObject *object)
 {
