@@ -41,12 +41,12 @@ ArvGcNode * 	arv_gc_enumeration_new 				(void);
 const GSList *	arv_gc_enumeration_get_entries			(ArvGcEnumeration *enumeration);
 
 const char *	arv_gc_enumeration_get_string_value		(ArvGcEnumeration *enumeration, GError **error);
-void		arv_gc_enumeration_set_string_value		(ArvGcEnumeration *enumeration, const char *value, GError **error);
+gboolean	arv_gc_enumeration_set_string_value		(ArvGcEnumeration *enumeration, const char *value, GError **error);
 gint64 		arv_gc_enumeration_get_int_value		(ArvGcEnumeration *enumeration, GError **error);
-void		arv_gc_enumeration_set_int_value		(ArvGcEnumeration *enumeration, gint64 value, GError **error);
-gint64 *	arv_gc_enumeration_get_available_int_values	(ArvGcEnumeration *enumeration,	guint *n_values, GError **error);
-const char **	arv_gc_enumeration_get_available_string_values	(ArvGcEnumeration *enumeration,	guint *n_values, GError **error);
-const char **	arv_gc_enumeration_get_available_display_names 	(ArvGcEnumeration *enumeration, guint *n_values, GError **error);
+gboolean	arv_gc_enumeration_set_int_value		(ArvGcEnumeration *enumeration, gint64 value, GError **error);
+gint64 *	arv_gc_enumeration_dup_available_int_values	(ArvGcEnumeration *enumeration,	guint *n_values, GError **error);
+const char **	arv_gc_enumeration_dup_available_string_values	(ArvGcEnumeration *enumeration,	guint *n_values, GError **error);
+const char **	arv_gc_enumeration_dup_available_display_names 	(ArvGcEnumeration *enumeration, guint *n_values, GError **error);
 
 G_END_DECLS
 
