@@ -33,27 +33,9 @@
 G_BEGIN_DECLS
 
 #define ARV_TYPE_GC_INVALIDATOR_NODE             (arv_gc_invalidator_node_get_type ())
-#define ARV_GC_INVALIDATOR_NODE(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), ARV_TYPE_GC_INVALIDATOR_NODE, ArvGcInvalidatorNode))
-#define ARV_GC_INVALIDATOR_NODE_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), ARV_TYPE_GC_INVALIDATOR_NODE, ArvGcInvalidatorNodeClass))
-#define ARV_IS_GC_INVALIDATOR_NODE(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ARV_TYPE_GC_INVALIDATOR_NODE))
-#define ARV_IS_GC_INVALIDATOR_NODE_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), ARV_TYPE_GC_INVALIDATOR_NODE))
-#define ARV_GC_INVALIDATOR_NODE_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS((obj), ARV_TYPE_GC_INVALIDATOR_NODE, ArvGcInvalidatorNodeClass))
+G_DECLARE_FINAL_TYPE (ArvGcInvalidatorNode, arv_gc_invalidator_node, ARV, GC_INVALIDATOR_NODE, ArvGcPropertyNode)
 
-typedef struct _ArvGcInvalidatorNodeClass ArvGcInvalidatorNodeClass;
-
-struct _ArvGcInvalidatorNode {
-	ArvGcPropertyNode	base;
-
-	guint64 change_index;
-};
-
-struct _ArvGcInvalidatorNodeClass {
-	ArvGcPropertyNodeClass parent_class;
-};
-
-GType 		arv_gc_invalidator_node_get_type 		(void);
 ArvGcNode * 	arv_gc_invalidator_node_new 			(void);
-
 gboolean 	arv_gc_invalidator_has_changed 			(ArvGcInvalidatorNode *self);
 
 G_END_DECLS
