@@ -79,7 +79,6 @@ typedef struct _ArvGcSelector		ArvGcSelector;
 typedef struct _ArvInterface 		ArvInterface;
 typedef struct _ArvDevice 		ArvDevice;
 typedef struct _ArvStream 		ArvStream;
-typedef struct _ArvBuffer 		ArvBuffer;
 typedef struct _ArvChunkParser		ArvChunkParser;
 
 typedef struct _ArvGvInterface 		ArvGvInterface;
@@ -92,9 +91,6 @@ typedef struct _ArvUvDevice		ArvUvDevice;
 typedef struct _ArvUvStream		ArvUvStream;
 #endif
 
-typedef struct _ArvFakeInterface	ArvFakeInterface;
-typedef struct _ArvFakeDevice		ArvFakeDevice;
-typedef struct _ArvFakeStream		ArvFakeStream;
 typedef struct _ArvFakeCamera		ArvFakeCamera;
 
 typedef struct _ArvGvFakeCamera		ArvGvFakeCamera;
@@ -102,8 +98,6 @@ typedef struct _ArvGvFakeCamera		ArvGvFakeCamera;
 typedef struct _ArvZip			ArvZip;
 typedef struct _ArvZipFile 		ArvZipFile;
 
-typedef struct _ArvXmlSchema 		ArvXmlSchema;
-
 G_END_DECLS
 
 #endif
