@@ -8,7 +8,7 @@ main (int argc, char **argv)
 	ArvCamera *camera;
 	ArvBuffer *buffer;
 
-	camera = arv_camera_new (argc > 1 ? argv[1] : NULL);
+	camera = arv_camera_new (argc > 1 ? argv[1] : NULL, NULL);
 	buffer = arv_camera_acquisition (camera, 0, NULL);
 
 	if (ARV_IS_BUFFER (buffer))
