@@ -76,7 +76,7 @@ main (int argc, char **argv)
 	else
 		g_print ("Looking for camera '%s'\n", arv_option_camera_name);
 
-	device = arv_open_device (arv_option_camera_name);
+	device = arv_open_device (arv_option_camera_name, NULL);
 	if (device != NULL) {
 		ArvGc *genicam;
 		ArvGcNode *node;
@@ -183,7 +183,7 @@ main (int argc, char **argv)
 			g_print ("reverse x           = %s\n", v_boolean ? "TRUE" : "FALSE");
 		}
 
-		stream = arv_device_create_stream (device, NULL, NULL);
+		stream = arv_device_create_stream (device, NULL, NULL, NULL);
 		if (arv_option_auto_buffer)
 			g_object_set (stream,
 				      "socket-buffer", ARV_GV_STREAM_SOCKET_BUFFER_AUTO,
@@ -240,9 +240,9 @@ main (int argc, char **argv)
 
 		arv_stream_get_statistics (stream, &n_processed_buffers, &n_failures, &n_underruns);
 
-		g_print ("Processed buffers = %Lu\n", (unsigned long long) n_processed_buffers);
-		g_print ("Failures          = %Lu\n", (unsigned long long) n_failures);
-		g_print ("Underruns         = %Lu\n", (unsigned long long) n_underruns);
+		g_print ("Processed buffers = %llu\n", (unsigned long long) n_processed_buffers);
+		g_print ("Failures          = %llu\n", (unsigned long long) n_failures);
+		g_print ("Underruns         = %llu\n", (unsigned long long) n_underruns);
 
 		node = arv_gc_get_node (genicam, "AcquisitionStop");
 		arv_gc_command_execute (ARV_GC_COMMAND (node), NULL);
