@@ -1,14 +1,17 @@
 import gi
+import os
 
 gi.require_version ('Aravis', '0.8')
 
 from gi.repository import Aravis
 
+Aravis.set_fake_camera_genicam_filename (os.getenv ('FAKE_GENICAM_PATH'))
+
 Aravis.enable_interface ("Fake")
 
 camera = Aravis.Camera.new ("Fake_1")
 
-assert camera != None
+assert camera is not None
 
 camera.set_region (10,20,100,200)
 camera.set_frame_rate (50.0)
